Package: ternarynet
Version: 1.56.0
Date: 2024-02-19
Title: Ternary Network Estimation
Description: Gene-regulatory network (GRN) modeling seeks to infer 
        dependencies between genes and thereby provide insight into 
        the regulatory relationships that exist within a cell. 
        This package provides a computational Bayesian approach to
        GRN estimation from perturbation experiments using a ternary 
        network model, in which gene expression is discretized into 
        one of 3 states: up, unchanged, or down). The ternarynet package
        includes a parallel implementation of the replica exchange Monte 
        Carlo algorithm for fitting network models, using MPI.
Author: Matthew N. McCall <mccallm@gmail.com>, 
        Anthony Almudevar <Anthony_Alumudevar@urmc.rochester.edu>,
        David Burton <David_Burton@urmc.rochester.edu>,
        Harry Stern <harry.stern@rochester.edu>
Authors@R: c(
  person("McCall","Matthew", 
         email="mccallm@gmail.com",
         role=c("aut","cre")),
  person("Almudevar","Anthony",
         email="Anthony_Almudevar@urmc.rochester.edu",
         role=c("aut")),
  person("Burton","David",
         email="David_Burton@urmc.rochester.edu",
         role=c("aut")),
  person("Stern","Harry",
         email="harry.stern@rochester.edu",
         role=c("aut")))
Depends: R (>= 4.0)
Imports: utils, igraph, methods, graphics, stats, BiocParallel
Suggests: testthat
Enhances: Rmpi, snow
License: GPL (>= 2)
biocViews: Software, CellBiology, GraphAndNetwork, Network, Bayesian
NeedsCompilation: yes
Packaged: 2026-04-29 01:08:13 UTC; biocbuild
Maintainer: McCall N. Matthew <mccallm@gmail.com>
git_url: https://git.bioconductor.org/packages/ternarynet
git_branch: RELEASE_3_23
git_last_commit: 8a6bb8d
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.23
Date/Publication: 2026-04-28
