## slot getters
setGeneric("perturbationObj", function(x) standardGeneric("perturbationObj"))
setGeneric("steadyStateObj", function(x) standardGeneric("steadyStateObj"))
setGeneric("geneNames", function(x) standardGeneric("geneNames"))
setGeneric("experimentNames", function(x) standardGeneric("experimentNames"))
setGeneric("degreeObjMin", function(x) standardGeneric("degreeObjMin"))
setGeneric("graphObjMin", function(x) standardGeneric("graphObjMin"))
setGeneric("tableObjMin", function(x) standardGeneric("tableObjMin"))
setGeneric("newScore", function(x) standardGeneric("newScore"))
setGeneric("minScore", function(x) standardGeneric("minScore"))
setGeneric("finalTemperature", function(x) standardGeneric("finalTemperature"))
setGeneric("xSeed", function(x) standardGeneric("xSeed"))
setGeneric("inputParams", function(x) standardGeneric("inputParams"))
setGeneric("scores", function(x) standardGeneric("scores"))
setGeneric("degreeObjs", function(x) standardGeneric("degreeObjs"))
setGeneric("graphObjs", function(x) standardGeneric("graphObjs"))
setGeneric("tableObjs", function(x) standardGeneric("tableObjs"))
setGeneric("perturbationType", function(x) standardGeneric("perturbationType"))
setGeneric("scoreType", function(x) standardGeneric("scoreType"))
setGeneric("backupStage", function(x) standardGeneric("backupStage"))
setGeneric("maxStage", function(x) standardGeneric("maxStage"))
setGeneric("maxTransition", function(x) standardGeneric("maxTransition"))
setGeneric("epsilon", function(x) standardGeneric("epsilon"))
setGeneric("beta0", function(x) standardGeneric("beta0"))
setGeneric("chi0", function(x) standardGeneric("chi0"))
setGeneric("delta", function(x) standardGeneric("delta"))
setGeneric("ne", function(x) standardGeneric("ne"))
setGeneric("m0", function(x) standardGeneric("m0"))
setGeneric("maxDegree", function(x) standardGeneric("maxDegree"))
setGeneric("pAddParent", function(x) standardGeneric("pAddParent"))
setGeneric("pExchangeParent", function(x) standardGeneric("pExchangeParent"))
setGeneric("neighborDegree", function(x) standardGeneric("neighborDegree"))
setGeneric("pNeighborhood", function(x) standardGeneric("pNeighborhood"))
setGeneric("rho", function(x) standardGeneric("rho"))
setGeneric("edgePenalty", function(x) standardGeneric("edgePenalty"))
setGeneric("traces", function(x) standardGeneric("traces"))
setGeneric("stageCount", function(x) standardGeneric("stageCount"))

## slot setters
setGeneric("perturbationObj<-", function(x, value) standardGeneric("perturbationObj<-"))
setGeneric("steadyStateObj<-", function(x, value) standardGeneric("steadyStateObj<-"))
setGeneric("geneNames<-", function(x, value) standardGeneric("geneNames<-"))
setGeneric("experimentNames<-", function(x, value) standardGeneric("experimentNames<-"))
setGeneric("degreeObjMin<-", function(x, value) standardGeneric("degreeObjMin<-"))
setGeneric("graphObjMin<-", function(x, value) standardGeneric("graphObjMin<-"))
setGeneric("tableObjMin<-", function(x, value) standardGeneric("tableObjMin<-"))
setGeneric("newScore<-", function(x, value) standardGeneric("newScore<-"))
setGeneric("minScore<-", function(x, value) standardGeneric("minScore<-"))
setGeneric("finalTemperature<-", function(x, value) standardGeneric("finalTemperature<-"))
setGeneric("xSeed<-", function(x, value) standardGeneric("xSeed<-"))
setGeneric("inputParams<-", function(x, value) standardGeneric("inputParams<-"))
setGeneric("scores<-", function(x, value) standardGeneric("scores<-"))
setGeneric("degreeObjs<-", function(x, value) standardGeneric("degreeObjs<-"))
setGeneric("graphObjs<-", function(x, value) standardGeneric("graphObjs<-"))
setGeneric("tableObjs<-", function(x, value) standardGeneric("tableObjs<-"))
setGeneric("perturbationType<-", function(x, value) standardGeneric("perturbationType<-"))
setGeneric("scoreType<-", function(x, value) standardGeneric("scoreType<-"))
setGeneric("backupStage<-", function(x, value) standardGeneric("backupStage<-"))
setGeneric("maxStage<-", function(x, value) standardGeneric("maxStage<-"))
setGeneric("maxTransition<-", function(x, value) standardGeneric("maxTransition<-"))
setGeneric("epsilon<-", function(x, value) standardGeneric("epsilon<-"))
setGeneric("beta0<-", function(x, value) standardGeneric("beta0<-"))
setGeneric("chi0<-", function(x, value) standardGeneric("chi0<-"))
setGeneric("delta<-", function(x, value) standardGeneric("delta<-"))
setGeneric("ne<-", function(x, value) standardGeneric("ne<-"))
setGeneric("m0<-", function(x, value) standardGeneric("m0<-"))
setGeneric("maxDegree<-", function(x, value) standardGeneric("maxDegree<-"))
setGeneric("pAddParent<-", function(x, value) standardGeneric("pAddParent<-"))
setGeneric("pExchangeParent<-", function(x, value) standardGeneric("pExchangeParent<-"))
setGeneric("neighborDegree<-", function(x, value) standardGeneric("neighborDegree<-"))
setGeneric("pNeighborhood<-", function(x, value) standardGeneric("pNeighborhood<-"))
setGeneric("rho<-", function(x, value) standardGeneric("rho<-"))
setGeneric("edgePenalty<-", function(x, value) standardGeneric("edgePenalty<-"))
setGeneric("traces<-", function(x, value) standardGeneric("traces<-"))
setGeneric("stageCount<-", function(x, value) standardGeneric("stageCount<-"))
